@@ -7,9 +7,11 @@
 #' @return several tables and lists with all basic stats. Check \code{\link[hierfstat]{basic.stats}} for details.
 #' @export
 #' @author Bernd Gruber (bugs? Post to \url{https://groups.google.com/d/forum/dartr})
+#' @examples 
+#' gl.basic.stats(possums.gl)
 
 gl.basic.stats <- function(gl, digits=4)
 {
-  out <- basic.stats(genind2hierfstat(gl2gi(gl, v = 0)), digits = digits)
+  out <- basic.stats(genind2hierfstat(gl2gi(gl, verbose = 0)), digits = digits)
   return(out)
 }
