@@ -191,7 +191,7 @@ gl.report.hwe <- function(x, subset="each", plot=FALSE, method="ChiSquare", alph
     } 
     
     # Determine the page layout for plots based on the number of populations to plot   
-    graphics::layout(mat = matrix(c(1,1),1,1, byrow=FALSE))
+    
     if (npops2plot > 1){
       if (npops2plot == 2) {
         graphics::layout(matrix(c(1,2), 1, 2, byrow = TRUE),widths=c(0.5,0.5))
@@ -208,6 +208,7 @@ gl.report.hwe <- function(x, subset="each", plot=FALSE, method="ChiSquare", alph
       }
     } else {
       if(verbose >= 2){cat("  Plotting one ternary plot\n")}
+      graphics::layout(mat = matrix(1,1,1, byrow=FALSE))
     }
  
     # Plot the tertiary plots
@@ -238,7 +239,7 @@ gl.report.hwe <- function(x, subset="each", plot=FALSE, method="ChiSquare", alph
       } 
     }
   }
-  graphics::layout(mat = matrix(c(1,1),1,1, byrow=FALSE))
+  #graphics::layout(mat = matrix(c(1,1),1,1, byrow=FALSE))
   
   #### Report the results
   
